==> flutter_addtoapp_bridge-0.0.6.tar.gz: test/flutter_addtoapp_bridge_test.dart <==
import 'package:flutter/src/services/message_codec.dart';
import 'package:flutter_addtoapp_bridge/flutter_addtoapp_bridge.dart';
import 'package:flutter_addtoapp_bridge/flutter_addtoapp_bridge_method_channel.dart';
import 'package:flutter_addtoapp_bridge/flutter_addtoapp_bridge_platform_interface.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

class MockFlutterAddtoappBridgePlatform with MockPlatformInterfaceMixin implements FlutterAddtoappBridgePlatform {
  @override
  Future callPlatform(String key, [arguments]) => Future.value('42');

  @override
  void setMethodCallHandler(Future Function(MethodCall call)? handler) {}

  @override
  Future<double> getFloat(String key, [defaultValue = 0.0]) {
    return Future.value(0.0);
  }

  @override
  Future<int> getLong(String key, [defaultValue = 0]) {
    return Future.value(0);
  }

  @override
  Future<String> getPlatformVersion() {
    return Future.value('0');
  }

  @override
  Future<String> getString(String key, [defaultValue = ""]) {
    return Future.value('0');
  }

  @override
  Future<bool> isAddToApp() {
    return Future.value(false);
  }

  @override
  Future<String> putFloat(String key, String value) {
    return Future.value('0');
  }

  @override
  Future<String> putLong(String key, String value) {
    return Future.value('0');
  }

  @override
  Future<String> putString(String key, String value) {
    return Future.value('0');
  }
}

void main() {
  final FlutterAddtoappBridgePlatform initialPlatform = FlutterAddtoappBridgePlatform.instance;

  test('$MethodChannelFlutterAddtoappBridge is the default instance', () {
    expect(initialPlatform, isInstanceOf<MethodChannelFlutterAddtoappBridge>());
  });

  test('getPlatformVersion', () async {
    FlutterAddtoappBridge flutterAddtoappBridgePlugin = FlutterAddtoappBridge();
    MockFlutterAddtoappBridgePlatform fakePlatform = MockFlutterAddtoappBridgePlatform();
    FlutterAddtoappBridgePlatform.instance = fakePlatform;

    expect(await flutterAddtoappBridgePlugin.getPlatformVersion(), '42');
  });
}

==> flutter_addtoapp_bridge-0.0.11.tar.gz: test/flutter_addtoapp_bridge_test.dart <==
import 'package:flutter/src/services/message_codec.dart';
import 'package:flutter_addtoapp_bridge/flutter_addtoapp_bridge.dart';
import 'package:flutter_addtoapp_bridge/flutter_addtoapp_bridge_method_channel.dart';
import 'package:flutter_addtoapp_bridge/flutter_addtoapp_bridge_platform_interface.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

class MockFlutterAddtoappBridgePlatform with MockPlatformInterfaceMixin implements FlutterAddtoappBridgePlatform {
  @override
  Future callPlatform(String key, [arguments]) => Future.value('42');

  @override
  void setMethodCallHandler(Future Function(MethodCall call)? handler) {}

  @override
  Future<double> getFloat(String key, {defaultValue = 0.0}) {
    return Future.value(0.0);
  }

  @override
  Future<int> getLong(String key, {defaultValue = 0}) {
    return Future.value(0);
  }

  @override
  Future<String> getPlatformVersion() {
    return Future.value('0');
  }

  @override
  Future<String> getString(String key, {defaultValue = ""}) {
    return Future.value('0');
  }

  @override
  Future<bool> isAddToApp() {
    return Future.value(false);
  }

  @override
  Future<String> putFloat(String key, double value) {
    return Future.value('0');
  }

  @override
  Future<String> putLong(String key, int value) {
    return Future.value('0');
  }

  @override
  Future<String> putString(String key, String value) {
    return Future.value('0');
  }
}

void main() {
  final FlutterAddtoappBridgePlatform initialPlatform = FlutterAddtoappBridgePlatform.instance;

  test('$MethodChannelFlutterAddtoappBridge is the default instance', () {
    expect(initialPlatform, isInstanceOf<MethodChannelFlutterAddtoappBridge>());
  });

  test('getPlatformVersion', () async {
    FlutterAddtoappBridge flutterAddtoappBridgePlugin = FlutterAddtoappBridge();
    MockFlutterAddtoappBridgePlatform fakePlatform = MockFlutterAddtoappBridgePlatform();
    FlutterAddtoappBridgePlatform.instance = fakePlatform;

    expect(await flutterAddtoappBridgePlugin.getPlatformVersion(), '42');
  });
}
